Module actor

Module actor 

Actor model for ReifyDB.

This module provides an actor model that provides identical semantics whether running on a single thread (WASM) or multiple OS threads (native).

Execution Model

  • Native: Actors run on threads with shared rayon pool for compute
  • WASM: Messages are processed inline (synchronously) when sent

All actor states must be Send.

Modules

context
Actor execution context.
mailbox
Actor mailbox and message sending types.
system
Unified actor system for ReifyDB.
testing
Testing utilities for actors.
timers
Timer utilities for actors.
traits
Core actor trait and associated types.