pub struct CancellationToken { /* private fields */ }Expand description
A cancellation token for signaling shutdown.
This is a simple atomic boolean that can be shared across actors. Supports hierarchical cancellation: a child token is considered cancelled when its parent is cancelled.
Implementations
Sourceimpl CancellationToken
impl CancellationToken
Sourcepub fn child_token(&self) -> Self
pub fn child_token(&self) -> Self
Create a child token that is cancelled when this token is cancelled.
Cancelling the child does NOT cancel the parent.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Check if cancellation was requested (on this token or its parent).