pub struct Context<M> { /* private fields */ }Expand description
Context provided to actors during execution.
Provides access to:
- Self reference (to give to other actors)
- Actor system (to spawn child actors and run compute)
- Cancellation (for graceful shutdown)
Implementations
Sourceimpl<M: Send + 'static> Context<M>
impl<M: Send + 'static> Context<M>
Sourcepub fn system(&self) -> &ActorSystem
pub fn system(&self) -> &ActorSystem
Get the actor system (for spawning child actors).
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Check if shutdown was requested.
Sourcepub fn cancellation_token(&self) -> CancellationToken
pub fn cancellation_token(&self) -> CancellationToken
Get the cancellation token.
Sourceimpl<M: Send + 'static> Context<M>
impl<M: Send + 'static> Context<M>
Sourcepub fn schedule_once<F: FnOnce() -> M + Send + 'static>(
&self,
delay: Duration,
factory: F,
) -> TimerHandle
pub fn schedule_once<F: FnOnce() -> M + Send + 'static>( &self, delay: Duration, factory: F, ) -> TimerHandle
Schedule a message to be sent to this actor after a delay.
Uses a factory function to create the message, so M doesn’t need to be Clone.
Returns a handle that can be used to cancel the timer.
Sourceimpl<M: Send + Sync + Clone + 'static> Context<M>
impl<M: Send + Sync + Clone + 'static> Context<M>
Sourcepub fn schedule_repeat(&self, interval: Duration, msg: M) -> TimerHandle
pub fn schedule_repeat(&self, interval: Duration, msg: M) -> TimerHandle
Schedule a message to be sent to this actor repeatedly at an interval.
The timer continues until cancelled or the actor is dropped. Returns a handle that can be used to cancel the timer.