SchedulerHandle

Struct SchedulerHandle 

pub struct SchedulerHandle { /* private fields */ }
Handle to the timer scheduler.

Used to schedule timers and shutdown the scheduler. Cloning the handle creates another reference to the same scheduler.

Implementations

Source

impl SchedulerHandle

pub fn new(pool: Arc<ThreadPool>) -> Self

Create and start a new scheduler.

Timer callbacks are dispatched to the given rayon thread pool.

pub fn schedule_once<F>(&self, delay: Duration, callback: F) -> TimerHandle
where F: FnOnce() + Send + 'static,

Schedule a callback to fire once after a delay.

Returns a handle that can be used to cancel the timer.

pub fn schedule_repeat<F>(&self, interval: Duration, callback: F) -> TimerHandle
where F: Fn() -> bool + Send + Sync + 'static,

Schedule a callback to fire repeatedly at an interval.

The callback returns true to continue or false to stop. Returns a handle that can be used to cancel the timer.

pub fn shared(&self) -> Self

pub fn shutdown(&mut self)

Shutdown the scheduler and wait for it to complete.