Core actor trait and associated types.
This module defines the fundamental abstractions for the actor model:
Actor: The trait that all actors must implementDirective: Control flow for actor schedulingActorConfig: Configuration for actor behavior
Enums
- Directive
- What the actor wants to do after handling a message.