pub struct MockClock { /* private fields */ }Expand description
Mock clock with atomic time storage for thread-safe access.
Implementations
Sourceimpl MockClock
impl MockClock
Sourcepub fn new(initial_nanos: u128) -> Self
pub fn new(initial_nanos: u128) -> Self
Create a new mock clock starting at the given nanoseconds
Sourcepub fn from_millis(millis: u64) -> Self
pub fn from_millis(millis: u64) -> Self
Create a new mock clock starting at the given milliseconds
Sourcepub fn now_micros(&self) -> u64
pub fn now_micros(&self) -> u64
Get current time in microseconds
Sourcepub fn now_millis(&self) -> u64
pub fn now_millis(&self) -> u64
Get current time in milliseconds
Sourcepub fn set_micros(&self, micros: u64)
pub fn set_micros(&self, micros: u64)
Set time to specific microseconds
Sourcepub fn set_millis(&self, millis: u64)
pub fn set_millis(&self, millis: u64)
Set time to specific milliseconds
Sourcepub fn advance_nanos(&self, nanos: u128)
pub fn advance_nanos(&self, nanos: u128)
Advance time by nanoseconds
Sourcepub fn advance_micros(&self, micros: u64)
pub fn advance_micros(&self, micros: u64)
Advance time by microseconds
Sourcepub fn advance_millis(&self, millis: u64)
pub fn advance_millis(&self, millis: u64)
Advance time by milliseconds