pub struct SchedulerHandle { /* private fields */ }Expand description
Handle to the timer scheduler.
Used to schedule timers and shutdown the scheduler. Cloning the handle creates another reference to the same scheduler.
Implementations
Sourceimpl SchedulerHandle
impl SchedulerHandle
Sourcepub fn new(pool: Arc<ThreadPool>) -> Self
pub fn new(pool: Arc<ThreadPool>) -> Self
Create and start a new scheduler.
Timer callbacks are dispatched to the given rayon thread pool.
Sourcepub fn schedule_once<F>(&self, delay: Duration, callback: F) -> TimerHandle
pub fn schedule_once<F>(&self, delay: Duration, callback: F) -> TimerHandle
Schedule a callback to fire once after a delay.
Returns a handle that can be used to cancel the timer.
Sourcepub fn schedule_repeat<F>(&self, interval: Duration, callback: F) -> TimerHandle
pub fn schedule_repeat<F>(&self, interval: Duration, callback: F) -> TimerHandle
Schedule a callback to fire repeatedly at an interval.
The callback returns true to continue or false to stop.
Returns a handle that can be used to cancel the timer.