Module rwlock

Module rwlock 

RwLock synchronization primitive.

Structs

RwLock
A reader-writer lock for shared read access and exclusive write access.
RwLockReadGuard
A guard providing read access to the data protected by an RwLock.
RwLockWriteGuard
A guard providing write access to the data protected by an RwLock.